.. This README is meant for consumption by humans and PyPI. PyPI can render rst files so please do not use Sphinx features.
   If you want to learn more about writing documentation, please check out: http://docs.plone.org/about/documentation_styleguide.html
   This text does not appear on PyPI or github. It is a comment.

.. image:: https://github.com/imio/imio.scan_logger/actions/workflows/plone-package.yml/badge.svg
    :target: https://github.com/imio/imio.scan_logger/actions/workflows/plone-package.yml

.. image:: https://coveralls.io/repos/github/imio/imio.scan_logger/badge.svg?branch=main
    :target: https://coveralls.io/github/imio/imio.scan_logger?branch=main
    :alt: Coveralls

.. image:: https://codecov.io/gh/imio/imio.scan_logger/branch/master/graph/badge.svg
    :target: https://codecov.io/gh/imio/imio.scan_logger

.. image:: https://img.shields.io/pypi/v/imio.scan_logger.svg
    :target: https://pypi.python.org/pypi/imio.scan_logger/
    :alt: Latest Version

.. image:: https://img.shields.io/pypi/status/imio.scan_logger.svg
    :target: https://pypi.python.org/pypi/imio.scan_logger
    :alt: Egg Status

.. image:: https://img.shields.io/pypi/pyversions/imio.scan_logger.svg?style=plastic   :alt: Supported - Python Versions

.. image:: https://img.shields.io/pypi/l/imio.scan_logger.svg
    :target: https://pypi.python.org/pypi/imio.scan_logger/
    :alt: License


================
imio.scan_logger
================

Plone product to save log files or messages from scan clients

..
   Features
   --------

   - @message-receiver endpoint to get rest message from clients


Translations
------------

This product has been translated into

- French


Installation
------------

Install imio.scan_logger by adding it to your buildout::

    [buildout]

    ...

    eggs =
        imio.scan_logger


and then running ``bin/buildout``


Authors
-------

sgeulette


Contributors
------------

Put your name here, you deserve it!

- ?


Contribute
----------

- Issue Tracker: https://github.com/imio/imio.scan_logger/issues
- Source Code: https://github.com/imio/imio.scan_logger


License
-------

The project is licensed under the GPLv2.
